Data Splitters
===============

This module provides utilities for splitting datasets into train/validation/test sets.

.. currentmodule:: torch_concepts.data.splitters

Summary
-------

**Splitter Classes**

.. autosummary::
   :toctree: generated
   :nosignatures:

   random.RandomSplitter
   coloring.ColoringSplitter


Class Documentation
-------------------

.. autoclass:: torch_concepts.data.splitters.random.RandomSplitter
   :members:
   :undoc-members:
   :show-inheritance:

.. autoclass:: torch_concepts.data.splitters.coloring.ColoringSplitter
   :members:
   :undoc-members:
   :show-inheritance:
